@@ -190,7 +190,7 @@ arma::mat pklj_bar(uword grid, uword n, arma::mat waveletcoefmat, double C0, dou
 		arma::vec w_density_unnorm = exp( LL(w_grid,l,j+1,n,waveletcoefmat,C0,C1,C2,C3,C4,C5) );
 		for(uword id=0; id<w_grid.n_elem; id++) 
 		{
-		  if(!is_finite(w_density_unnorm(id))) w_density_unnorm(id) = 1;
+		  if(!std::isfinite(w_density_unnorm(id))) w_density_unnorm(id) = 1;
 		}	
 		double sum_w = sum(w_density_unnorm.elem(regspace<uvec>(1,N-1))) + 0.5 * (w_density_unnorm(0)+w_density_unnorm(N));
 		arma::vec  w_density_norm = w_density_unnorm / sum_w;
